@@ -125,11 +125,11 @@ fastmks <- function(bandwidth=NA,
   }
 
   if (!identical(query, NA)) {
-    SetParamMat(p, "query", to_matrix(query))
+    SetParamMat(p, "query", to_matrix(query), TRUE)
   }
 
   if (!identical(reference, NA)) {
-    SetParamMat(p, "reference", to_matrix(reference))
+    SetParamMat(p, "reference", to_matrix(reference), TRUE)
   }
 
   if (!identical(scale, NA)) {
