@@ -186,7 +186,7 @@ linear_svm <- function(delta=NA,
   }
 
   if (!identical(test, NA)) {
-    SetParamMat(p, "test", to_matrix(test))
+    SetParamMat(p, "test", to_matrix(test), TRUE)
   }
 
   if (!identical(test_labels, NA)) {
@@ -198,7 +198,7 @@ linear_svm <- function(delta=NA,
   }
 
   if (!identical(training, NA)) {
-    SetParamMat(p, "training", to_matrix(training))
+    SetParamMat(p, "training", to_matrix(training), TRUE)
   }
 
   if (verbose) {
