@@ -164,7 +164,7 @@ logistic_regression <- function(batch_size=NA,
   }
 
   if (!identical(test, NA)) {
-    SetParamMat(p, "test", to_matrix(test))
+    SetParamMat(p, "test", to_matrix(test), TRUE)
   }
 
   if (!identical(tolerance, NA)) {
@@ -172,7 +172,7 @@ logistic_regression <- function(batch_size=NA,
   }
 
   if (!identical(training, NA)) {
-    SetParamMat(p, "training", to_matrix(training))
+    SetParamMat(p, "training", to_matrix(training), TRUE)
   }
 
   if (verbose) {
